@@ -1,41 +1,42 @@
-#[cfg(not(feature = "mpv"))]
-// #[cfg(all(feature = "gst", not(feature = "mpv")))]
+// mod internal_backend;
+// mod crossbeam;
+// mod symphonia_backend;
+#[cfg(all(feature = "gst", not(feature = "mpv")))]
 mod gstreamer_backend;
+#[cfg(not(any(feature = "mpv", feature = "gst")))]
+mod rusty_backend;
+// // #[cfg(all(feature = "gst", not(feature = "mpv")))]
 #[cfg(feature = "mpv")]
 mod mpv_backend;
 // #[cfg(not(any(feature = "mpv", feature = "gst")))]
 // mod rodio_backend;
-// mod symphonia_backend;
 use anyhow::Result;
-#[cfg(not(feature = "mpv"))]
-// #[cfg(all(feature = "gst", not(feature = "mpv")))]
-use gstreamer_backend::GStreamer;
 #[cfg(feature = "mpv")]
 use mpv_backend::Mpv;
 // #[cfg(not(any(feature = "mpv", feature = "gst")))]
 // use rodio_backend::RodioPlayer;
 // use symphonia_backend::Symphonia;
 pub struct GeneralPl {
-    // #[cfg(all(feature = "gst", not(feature = "mpv")))]
-    #[cfg(not(feature = "mpv"))]
-    player: GStreamer,
+    #[cfg(all(feature = "gst", not(feature = "mpv")))]
+    player: gstreamer_backend::GStreamer,
     #[cfg(feature = "mpv")]
     player: Mpv,
-    // #[cfg(not(any(feature = "mpv", feature = "gst")))]
     // player: RodioPlayer,
     // player: Symphonia,
+    // player: crossbeam::Player,
+    // player: symphonia_backend::Symphonia,
+    #[cfg(not(any(feature = "mpv", feature = "gst")))]
+    player: rusty_backend::Player,
 }
 
 impl Default for GeneralPl {
     fn default() -> Self {
-        // #[cfg(all(feature = "gst", not(feature = "mpv")))]
-        #[cfg(not(feature = "mpv"))]
-        let player = GStreamer::default();
+        #[cfg(all(feature = "gst", not(feature = "mpv")))]
+        let player = gstreamer_backend::GStreamer::default();
         #[cfg(feature = "mpv")]
         let player = Mpv::default();
-        // #[cfg(not(any(feature = "mpv", feature = "gst")))]
-        // // let player = RodioPlayer::default();
-        // let player = Symphonia::default();
+        #[cfg(not(any(feature = "mpv", feature = "gst")))]
+        let player = rusty_backend::Player::default();
         Self { player }
     }
 }
