@@ -1,6 +1,6 @@
 use crate::ui::components::Xywh;
-use anyhow::Result;
-use log::error;
+use anyhow::{bail, Result};
+// use log::error;
 use std::io::Write;
 use std::process::Child;
 use std::process::Stdio;
@@ -19,36 +19,36 @@ impl Default for UeInstance {
 }
 
 impl UeInstance {
-    pub fn draw_cover_ueberzug(&self, url: &str, draw_xywh: &Xywh) {
+    pub fn draw_cover_ueberzug(&self, url: &str, draw_xywh: &Xywh) -> Result<()> {
         if draw_xywh.width <= 1 || draw_xywh.height <= 1 {
-            return;
+            return Ok(());
         }
 
         // Ueberzug takes an area given in chars and fits the image to
         // that area (from the top left).
-
-        // Round up since the bottom might have empty space within
-        // the designated box
-
         let cmd = format!("{{\"action\":\"add\",\"scaler\":\"fit_contain\",\"identifier\":\"cover\",\"x\":{},\"y\":{},\"width\":{},\"height\":{},\"path\":\"{}\"}}\n",
-            draw_xywh.x, draw_xywh.y-1,
-            draw_xywh.width, draw_xywh.height,
-            url,
-        );
+        // TODO: right now the y position of ueberzug is not consistent, and could be a 0.5 difference
+                // draw_xywh.x, draw_xywh.y-1,
+                draw_xywh.x, draw_xywh.y-draw_xywh.height % 2,
+                draw_xywh.width,draw_xywh.height*2,
+                url,
+            );
 
         if let Err(e) = self.run_ueberzug_cmd(&cmd) {
-            error!("Failed to run Ueberzug: {}", e);
+            bail!("Failed to run Ueberzug: {}", e);
         }
+        Ok(())
     }
 
-    pub fn clear_cover_ueberzug(&self) {
+    pub fn clear_cover_ueberzug(&self) -> Result<()> {
         let cmd = "{\"action\": \"remove\", \"identifier\": \"cover\"}\n";
         if let Err(e) = self.run_ueberzug_cmd(cmd) {
-            error!("Failed to run Ueberzug: {}", e);
+            bail!("Failed to run Ueberzug: {}", e);
         }
+        Ok(())
     }
 
-    fn run_ueberzug_cmd(&self, cmd: &str) -> Result<(), std::io::Error> {
+    fn run_ueberzug_cmd(&self, cmd: &str) -> Result<()> {
         let mut ueberzug = self.ueberzug.write().unwrap();
 
         if ueberzug.is_none() {
