@@ -26,13 +26,11 @@
  * SOFTWARE.
  */
 use super::Msg;
-
 use tuirealm::command::{Cmd, CmdResult};
+use tuirealm::event::NoUserEvent;
 use tuirealm::props::{Alignment, Color, Style, TextModifiers};
 use tuirealm::tui::{layout::Rect, widgets::Paragraph};
-use tuirealm::{
-    AttrValue, Attribute, Component, Event, Frame, MockComponent, NoUserEvent, Props, State,
-};
+use tuirealm::{AttrValue, Attribute, Component, Event, Frame, MockComponent, Props, State};
 
 /// ## Label
 ///
