@@ -37,9 +37,9 @@ use crate::{
     ui::{Application, Id, Msg},
 };
 
-use crate::player::GStreamer;
+use crate::player::{GeneralP, GeneralPl};
 use crate::songtag::SongTag;
-use crate::ui::components::StyleColorSymbol;
+use crate::ui::components::{Keys, StyleColorSymbol};
 use crate::ui::{SearchLyricState, Status};
 use std::collections::VecDeque;
 use std::path::{Path, PathBuf};
@@ -78,12 +78,12 @@ pub struct Model {
     pub tree: Tree,
     pub playlist_items: VecDeque<Song>,
     pub config: Termusic,
-    pub player: GStreamer,
+    pub player: GeneralPl,
     pub status: Option<Status>,
     pub yanked_node_id: Option<String>,
     pub current_song: Option<Song>,
     pub tageditor_song: Option<Song>,
-    pub time_pos: u64,
+    pub time_pos: i64,
     pub lyric_line: String,
     youtube_options: YoutubeOptions,
     pub sender: Sender<UpdateComponents>,
@@ -98,6 +98,9 @@ pub struct Model {
     pub viuer_supported: bool,
     pub ce_themes: Vec<String>,
     pub ce_style_color_symbol: StyleColorSymbol,
+    pub ke_key_config: Keys,
+    #[cfg(feature = "mpris")]
+    pub mpris: mpris::Mpris,
 }
 
 impl Model {
@@ -110,7 +113,6 @@ impl Model {
         let p: &Path = Path::new(full_path.as_ref());
         let tree = Tree::new(Self::library_dir_tree(p, MAX_DEPTH));
 
-        let player = GStreamer::new();
         let (tx, rx): (Sender<UpdateComponents>, Receiver<UpdateComponents>) = mpsc::channel();
         let (tx2, rx2): (Sender<VecDeque<Song>>, Receiver<VecDeque<Song>>) = mpsc::channel();
         let (tx3, rx3): (Sender<SearchLyricState>, Receiver<SearchLyricState>) = mpsc::channel();
@@ -127,7 +129,7 @@ impl Model {
             terminal: TerminalBridge::new().expect("Could not initialize terminal"),
             playlist_items: VecDeque::with_capacity(100),
             config: config.clone(),
-            player,
+            player: GeneralPl::default(),
             yanked_node_id: None,
             status: None,
             current_song: None,
@@ -147,6 +149,9 @@ impl Model {
             viuer_supported,
             ce_themes: vec![],
             ce_style_color_symbol: StyleColorSymbol::default(),
+            ke_key_config: Keys::default(),
+            #[cfg(feature = "mpris")]
+            mpris: mpris::Mpris::default(),
         }
     }
     pub fn init_config(&mut self) {
